package edu.mermet.tp8;

import java.util.Properties;
import java.nio.file.Files;
import java.nio.file.Paths;
import java.io.FileInputStream;
import java.io.FileOutputStream;


public class Preferences {

	private static Preferences preferences;
	private static Properties prop;
	private static String env;
	private static String cheminDossier;
	private static String cheminPreferences;

	private Preferences(){
		prop = new Properties();

		//Récupération des chemins d'accès
		env = System.getenv("HOME");
		cheminDossier = env+"/.ihm";
		cheminPreferences = cheminDossier+"/preferences.xml";
	}

	/**
	* Initialise les préférences selon le fichier HOME/.ihm/preferences.xml
	*/
	public static Preferences getPreferences(){
		try{
			if(Preferences.preferences == null){
				Preferences.preferences = new Preferences();

				//Création du dossier .ihm si il n'existe pas
				if(! Files.isDirectory(Paths.get(cheminDossier))){
					Files.createDirectory(Paths.get(cheminDossier));
				}

				//Si le fichier de préférences n'existe pas alors on l'initialise
				if(! Files.exists(Paths.get(cheminPreferences))){
					initialiserPreferences();
				}

				//Récupération des préférences déjà existantes
				Preferences.prop.loadFromXML(new FileInputStream(cheminPreferences));

			}
		}
		catch(Exception e){e.printStackTrace();}
		return Preferences.preferences;
	}

	public void setPreference(String titre, String valeur){
		Preferences.prop.setProperty(titre, valeur);

	}

	public String getPreference(String titre){
		return Preferences.prop.getProperty(titre);
	}

	/**
	* Méthode d'enregistrement des préférences dans un fichier xml
	*/
	public void enregistrerPreferences(){
		try{
			Preferences.prop.storeToXML(new FileOutputStream(cheminPreferences), null);
		}catch(Exception e){e.printStackTrace();}
	}

	/**
	* Méthode d'initialisation des préférences lorsque le fichier n'existe pas déjà
	*/
	private static void initialiserPreferences(){
		try{
			Preferences.prop.setProperty("diaporama", "auto");
			Preferences.prop.setProperty("conversion", "auto");
			Preferences.prop.setProperty("boutons", "auto");
			Preferences.prop.setProperty("saisietexte", "auto");
			Preferences.prop.setProperty("suggestion", "vrai");

			Preferences.prop.storeToXML(new FileOutputStream(cheminPreferences), null);
		}catch(Exception e){e.printStackTrace();}
	}
}