package edu.mermet.tp8.fenetres;

import java.awt.GridLayout;
import java.awt.BorderLayout;
import java.awt.FlowLayout;
import java.awt.event.WindowAdapter;
import java.awt.event.WindowEvent;
import java.awt.event.ActionEvent;
import javax.swing.Action;
import javax.swing.AbstractAction;
import javax.swing.AbstractButton;
import javax.swing.ButtonGroup;
import javax.swing.JPanel;
import javax.swing.JRadioButton;
import javax.swing.JLabel;
import javax.swing.JButton;
import javax.swing.JDialog;
import java.util.HashMap;
import java.util.Enumeration;

import edu.mermet.tp8.Application;
import edu.mermet.tp8.Preferences;

public class JDialogConfig extends JDialog {

	private Application appli;
	private Preferences preferences;

	private final String auto    = "auto";
	private final String affiche = "afficher";
	private final String cache   = "cacher";

	private HashMap<String, ButtonGroup> hmBtns;
	private HashMap<String, String> hmTitreLbl;

	private Action actionValider;
	private Action actionAnnuler;

	public JDialogConfig(Application appli){
		super(appli, "Configuration des menus", true);
		this.appli = appli;
		preferences = Preferences.getPreferences();

		hmBtns = new HashMap<String, ButtonGroup>();
		hmBtns.put("conversion",  new ButtonGroup());
		hmBtns.put("saisietexte", new ButtonGroup());
		hmBtns.put("diaporama",   new ButtonGroup());
		hmBtns.put("boutons",     new ButtonGroup());

		hmTitreLbl = new HashMap<String, String>();
		hmTitreLbl.put("conversion", "ConversionCelsuis/Farenheit");
		hmTitreLbl.put("saisietexte", "Saisie de texte");
		hmTitreLbl.put("diaporama", "Diaporama");
		hmTitreLbl.put("boutons", "Boutons");
		
		init();

		setSize(500,200);
		setResizable(false);
		setLocationRelativeTo(appli);
		show();
		addWindowListener(new EcouteurFermeture());
	}

	private void init(){
		//Panel des choix
		JPanel panelChoix = new JPanel();
		panelChoix.setLayout(new GridLayout(4, 4));

		for(String titre : hmBtns.keySet()){
			ButtonGroup bg = hmBtns.get(titre);
			JRadioButton b1 = new JRadioButton(auto, false);
			JRadioButton b2 = new JRadioButton(affiche, false);
			JRadioButton b3 = new JRadioButton(cache, false);
			bg.add(b1);
			bg.add(b2);
			bg.add(b3);
			panelChoix.add(new JLabel(hmTitreLbl.get(titre)));
			panelChoix.add(b1);
			panelChoix.add(b2);
			panelChoix.add(b3);
		}

		//Panel des boutons
		JPanel pnlBtn = new JPanel();
		pnlBtn.setLayout(new FlowLayout());
		JButton btnValider = new JButton(new ActionValider(this));
		JButton btnAnnuler = new JButton(new ActionAnnuler(this));
		pnlBtn.add(btnValider);
		pnlBtn.add(btnAnnuler);

		add(panelChoix);
		add(pnlBtn, BorderLayout.SOUTH);

		for(String titre : hmBtns.keySet()){
            Enumeration<AbstractButton> enu = hmBtns.get(titre).getElements();
            	
			while(enu.hasMoreElements()){
				AbstractButton b = enu.nextElement();
				if(b.getText().equals(preferences.getPreference(titre)))
					b.setSelected(true);
			}
        }

	}

	class EcouteurFermeture extends WindowAdapter{

        public void windowClosing(WindowEvent e){
            appli.enableCommentFaire(true);
        }
    }

    private class ActionValider extends AbstractAction {
        private JDialogConfig f;
        public ActionValider(JDialogConfig f) {
            super("Valider");
            this.f=f;
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            for(String titre : hmBtns.keySet()){
            	Enumeration<AbstractButton> enu = hmBtns.get(titre).getElements();
            	
				while(enu.hasMoreElements()){
					AbstractButton b = enu.nextElement();
					if(b.isSelected())
						preferences.setPreference(titre, b.getText());
				}
            }
            preferences.enregistrerPreferences();
            f.dispose();
        }
    }

    private class ActionAnnuler extends AbstractAction {
        JDialogConfig f;
        public ActionAnnuler(JDialogConfig f) {
            super("Annuler");
            this.f=f;
        }

        @Override
        public void actionPerformed(ActionEvent ae) {
            f.dispose();
        }
    }
}